@@ -5,8 +5,12 @@ with_mock_api({
 
     expect_tibble(dlf_league, any.missing = FALSE, min.rows = 1)
 
-    jml_conn <- ff_connect(platform = "sleeper", league_id = 522458773317046272, season = 2020)
+    jml_conn <- ff_connect(platform = "sleeper", league_id = "522458773317046272", season = 2020)
     jml_league <- ff_league(jml_conn)
     expect_tibble(jml_league, any.missing = FALSE, min.rows = 1)
+
+    got_conn <- fleaflicker_connect(2020, 206154)
+    got_league <- ff_league(got_conn)
+    expect_tibble(got_league, min.rows = 1)
   })
 })
